@@ -7,8 +7,7 @@ import { WithCustomElementComponent } from '../element-registry';
 @NgModule({
   imports: [ CommonModule, CodeModule ],
   declarations: [ CodeExampleComponent ],
-  exports: [ CodeExampleComponent ],
-  entryComponents: [ CodeExampleComponent ]
+  exports: [ CodeExampleComponent ]
 })
 export class CodeExampleModule implements WithCustomElementComponent {
   customElementComponent: Type<any> = CodeExampleComponent;
