@@ -6,8 +6,7 @@ import { TocComponent } from './toc.component';
 
 @NgModule({
   imports: [ CommonModule, MatIconModule ],
-  declarations: [ TocComponent ],
-  entryComponents: [ TocComponent ],
+  declarations: [ TocComponent ]
 })
 export class TocModule implements WithCustomElementComponent {
   customElementComponent: Type<any> = TocComponent;
