@@ -27,12 +27,19 @@ export class ReportingErrorHandler extends ErrorHandler {
     this.reportError(error);
   }
 
-  private reportError(error: string | Error) {
-    if (this.window !== null && this.window.onerror !== null) {
-      if (typeof error === 'string') {
-          this.window.onerror(error);
-      } else {
+  private reportError(error: unknown) {
+    if (this.window.onerror) {
+      if (error instanceof Error) {
         this.window.onerror(error.message, undefined, undefined, undefined, error);
+      } else {
+        if (typeof error === 'object') {
+          try {
+            error = JSON.stringify(error);
+          } catch {
+            // Ignore the error and just let it be stringified.
+          }
+        }
+        this.window.onerror(`${error}`);
       }
     }
   }
