@@ -3,14 +3,6 @@
 // `ng build --env=prod` then `environment.prod.ts` will be used instead.
 // The list of which env maps to which file can be found in `angular-cli.json`.
 
-
-// Reflect.metadata polyfill is only needed in the JIT/dev mode.
-//
-// In order to load these polyfills early enough (before app code), polyfill.ts imports this file to
-// to change the order in the final bundle.
-import 'core-js/es/reflect';
-
-
 export const environment = {
   gaId: 'UA-36380079-2', // Development id
   production: false,
