@@ -6,11 +6,11 @@ const operators = require('rxjs/operators');
 const rxSnapshot = require('./rx.json');
 const operatorsSnapshot = require('./operators.json');
 
-const coldObservalbe = require('rxjs/internal/testing/ColdObservable');
+const coldObservable = require('rxjs/internal/testing/ColdObservable');
 
 assert.ok(rx, 'main export should exists');
 assert.ok(operators, 'operator export should exists');
-assert.ok(coldObservalbe, 'internal can be imported');
+assert.ok(coldObservable, 'internal can be imported');
 
 assert.deepStrictEqual(Object.keys(rx).sort(), rxSnapshot.sort(), 'main export should include exports');
 assert.deepStrictEqual(Object.keys(operators).sort(), operatorsSnapshot.sort(), 'operator export should include exports');
