@@ -13,6 +13,6 @@ it('should enforce compareTo to be the same type of Observable', () => {
   const a = of(1, 2, 3).pipe(sequenceEqual(of('a'))); // $ExpectError
 });
 
-it('should infer correcly given comparor parameter', () => {
+it('should infer correctly given comparator parameter', () => {
   const a = of(1, 2, 3).pipe(sequenceEqual(of(1), (val1, val2) => val1 === val2)); // $ExpectType Observable<boolean>
 });
