@@ -442,17 +442,16 @@ describe('Subject', () => {
       },
     };
 
-    const sub = Subject.create(destination, source);
+    const sub: Subject<any> = Subject.create(destination, source);
 
-    sub.subscribe(
-      function (x: number) {
+    sub.subscribe({
+      next: function (x: number) {
         output.push(x);
       },
-      null,
-      () => {
+      complete: () => {
         outputComplete = true;
       }
-    );
+    });
 
     sub.next('a');
     sub.next('b');
@@ -492,17 +491,16 @@ describe('Subject', () => {
       },
     };
 
-    const sub = Subject.create(destination, source);
+    const sub: Subject<any> = Subject.create(destination, source);
 
-    sub.subscribe(
-      function (x: number) {
+    sub.subscribe({
+      next: function (x: number) {
         output.push(x);
       },
-      null,
-      () => {
+      complete: () => {
         outputComplete = true;
       }
-    );
+    });
 
     sub.next('a');
     sub.next('b');
