@@ -7,10 +7,10 @@ describe('index', () => {
   });
 
   it('should export Ajax data classes', () => {
-    expect(index.AjaxResponse).to.exist;
     expect(index.AjaxError).to.exist;
     expect(index.AjaxTimeoutError).to.exist;
     // Interfaces can be checked by creating a variable of that type
     let ajaxRequest: index.AjaxRequest;
+    let ajaxResponse: index.AjaxResponse<object>;
   });
 });
